#if defined _ncodmod_included
  #endinput
#endif
#define _ncodmod_included

enum NCodState {
	NCODSTATE_DISABLE,
	NCODSTATE_ENABLE,
	NCODSTATE_USE,
	NCODSTATE_SPAWN
}

enum NCodStatist
{
	NCODSTATIST_HEALTH,
	NCODSTATIST_STRENGTH,
	NCODSTATIST_INTELLIGENCE,
	NCODSTATIST_CONDITION,
	NCODSTATIST_LEVEL,
	NCODSTATIST_EXPERIENCE
}

enum NCodTeams {
	NCODTEAM_ALL,
	NCODTEAM_TERRORIST,
	NCODTEAM_AMERICA
}

enum NCodInfoType {
	NCODINFOTYPE_CHAT,
	NCODINFOTYPE_HUD,
	NCODINFOTYPE_BOTH
}

enum NCodInfoColor {
	NCODINFOCOLOR_NORMAL,
	NCODINFOCOLOR_INFORMATION,
	NCODINFOCOLOR_WARNING,
	NCODINFOCOLOR_PANIC
}

/**
 * Rejestruje nowa klase
 *
 * @type					native
 *
 * @param szName			Nazwa klasy
 * @param szDescription		Opis klasy
 * @param iHealth			Poczatkowe zycie klasy
 * @param iStrength			Poczatkowa wytrzymalosc klasy
 * @param iInteligence		Poczatkowa inteligencja klasy
 * @param iCondition		Poczatkowa kondycja klasy
 * @param iWeapons			Bronie klasy ( bitsum'a )
 * @param iTeam				Druzyna gracza ( wartosc opcjonalna )
 * @param iAccessFlags		Flagi potrzebne do uzywania klasy ( wartosc opcjonalna )
 *
 * @return					Zwraca id klasy badz -1 jezeli rejestracja sie nie powiedzie
 */
native ncod_registerClass( const szName[ ], const szDescription[ ], const iHealth, const iStrength, const iInteligence, const iCondition, const iWeapons, const NCodTeams: iTeam = NCODTEAM_ALL, const iAccessFlags = 0 );

/**
 * Rejestruje nowy perk
 *
 * @type					native
 *
 * @param szName			Nazwa perku
 * @param szDescription		Opis perku
 * @param iAccessFlags		Flagi potrzebne do uzywania perku ( wartosc opcjonalna )
 *
 * @return					Zwraca id perku badz -1 jezeli rejestracja sie nie powiedzie
 */
native ncod_registerPerk( const szName[ ], const szDescription[ ], const iAccessFlags = 0 );

/**
 * Pobiera wartosc statystyki
 *
 * @type					native
 *
 * @param id				Index gracza
 * @param iStatist			Index statystyki ( patrz: struktura NCodStatist )
 *
 * @return					Zwraca wartosc statystyki
 */
native ncod_getUserStatist( id, NCodStatist: iStatist );

/**
 * Ustawia wartosc statystyki
 *
 * @type 					native
 *
 * @param id				Index gracza
 * @param iStatist			Index statystyki ( patrz: struktura NCodStatist )
 * @param iValue			Wartosc do ustawienia
 *
 * @return					Zwraca 0 jezeli sie powiedzie, badz -1 jezeli sie nie powiedzie
 */
native ncod_setUserStatist( id, NCodStatist: iStatist, iValue );

/**
 * Dodaje wartosc do statystyki
 *
 * @type 					define
 *
 * @param id				Index gracza
 * @param iStatist			Index statystyki ( patrz: struktura NCodStatist )
 * @param iValue			Wartosc do ustawienia
 *
 * @return					Zwraca 0 jezeli sie powiedzie, badz -1 jezeli sie nie powiedzie
 */
#define ncod_addToUserStatist(%1,%2,%3) ncod_setUserStatist(%1,%2,ncod_getUserStatist(%1,%2)+%3)

/**
 * Pobiera wartosc obrazen od inteligencji
 *
 * @type					define
 *
 * @param id				Index gracza
 * @param fMultiplier		Mnoznik  obrazen od inteligencjii
 *
 * @return					Zwraca ilosc obrazen z inteligencjii wd. podanego mnoznika
 */
#define ncod_getInteligenceDamage(%1,%2) float( ncod_getUserStatist(%1,NCODSTATIST_INTELLIGENCE)*%2 ) 

/**
 * Pobiera wartosc obrazen od inteligencji
 *
 * @type					native
 *
 * @param id				Index gracza
 * @param iType				Typ wysylaniej wiadomosci ( patrz: struktura NCodInfoType )
 * @param iColor			Kolor wysylanej wiadomosci ( patrz: struktura NCodInfoColor )
 * @param szMessage			Tresc wiadomosci
 *
 * @return					Zwraca 0 jezeli sie powiedzie, badz -1 jezeli sie nie powiedzie
 */
native ncod_printInformation( id, NCodInfoType: iType, NCodInfoColor: iColor, const szMessage[ ], any:... );

/**
 * Rejetruje mozliwosc edycji NewCodMod HUD w pluginie
 *
 * @type					native
 *
 * @return					void
 *
 * @note: Powinno zostac wykonane nie pozniej niz w forwardz'ie plugin_init
 */
native ncod_registerHUDAddon( );

/**
 * Forward wykonywany przy zmianie stanu klasy
 *
 * @type					forward
 *
 * @param id				Index gracza
 * @param iClass			Index klasy
 * @param iState			Status gracza ( patrz: struktura NCodState )
 */
forward ncod_classChangeState( id, iClass, NCodState: iState );

/**
 * Forward wykonywany przy zmianie stanu perku
 *
 * @type					forward
 *
 * @param id				Index gracza
 * @param iClass			Index perku
 * @param iState			Status perku ( patrz: struktura NCodState )
 */
forward ncod_perkChangeState( id, iPerk, NCodState: iState );

/**
 * Forward wykonywany przy odswiezaniu HUD'a
 *
 * @type					forward
 *
 * @param id				Index gracza
 * @param &szText			Tresc HUD'a
 */
forward ncod_hudRefresh( id, szText[ 128 ] );